@@ -4,11 +4,11 @@ from __future__ import absolute_import
 
 import logging
 from collections import OrderedDict
-
-import six
+from copy import deepcopy
 
 from eventtracking.processors.exceptions import EventEmissionExit
 
+
 LOG = logging.getLogger(__name__)
 
 
@@ -82,6 +82,8 @@ class RoutingBackend:
 
         Logs and swallows all `Exception`.
         """
+        event = deepcopy(event)
+
         try:
             processed_event = self.process_event(event)
         except EventEmissionExit:
@@ -127,7 +129,7 @@ class RoutingBackend:
         Logs and swallows all `Exception`.
         """
 
-        for name, backend in six.iteritems(self.backends):
+        for name, backend in self.backends.items():
             try:
                 backend.send(event)
             except Exception:  # pylint: disable=broad-except
